import type { NextApiRequest, NextApiResponse } from "next"
import { rejectionError } from "./errors"
import logging from "./logging"

export default function sendError<T>(
  req: NextApiRequest,
  res: NextApiResponse<T>,
  err: rejectionError | Error,
) {
  // If something went wrong, let the client know with status 500
  res.status("statusCode" in err ? err.statusCode : 500).end()
  logging(
    err.message,
    "type" in err && err.type
      ? err.type
      : ["solved" in err && err.solved ? "debug" : "error"],
    req,
  )
  if ("name" in err) console.log(err)
}
